==> ejc-dataexchange-api-3.0.0-20220302.054731-8-sources.jar: com/ejianc/business/dataexchange/vo/JzsVo.java <==
package com.ejianc.business.dataexchange.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

public class JzsVo extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String name;

    private String compamy;    //单位

    private String idCode;  //通过身份证号计算年龄

    private String title;  //职称

    private String certificate; //证书

    private String registered; //注册单位

    private String management; //管理单位

    private String registeredNo; //注册编号

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effactiveDate;//有效日期

    private String addItemA;//专业增项1；

    private String addItemB;//专业增项2

    private String addItemC;//专业增项3；

    private String addItemD;//专业增项4

    public String getAddItemC() {
        return addItemC;
    }

    public void setAddItemC(String addItemC) {
        this.addItemC = addItemC;
    }

    public String getAddItemD() {
        return addItemD;
    }

    public void setAddItemD(String addItemD) {
        this.addItemD = addItemD;
    }



    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCompamy() {
        return compamy;
    }

    public void setCompamy(String compamy) {
        this.compamy = compamy;
    }

    public String getIdCode() {
        return idCode;
    }

    public void setIdCode(String idCode) {
        this.idCode = idCode;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getCertificate() {
        return certificate;
    }

    public void setCertificate(String certificate) {
        this.certificate = certificate;
    }

    public String getRegistered() {
        return registered;
    }

    public void setRegistered(String registered) {
        this.registered = registered;
    }

    public String getManagement() {
        return management;
    }

    public void setManagement(String management) {
        this.management = management;
    }

    public String getRegisteredNo() {
        return registeredNo;
    }

    public void setRegisteredNo(String registeredNo) {
        this.registeredNo = registeredNo;
    }

    public Date getEffactiveDate() {
        return effactiveDate;
    }

    public void setEffactiveDate(Date effactiveDate) {
        this.effactiveDate = effactiveDate;
    }

    public String getAddItemA() {
        return addItemA;
    }

    public void setAddItemA(String addItemA) {
        this.addItemA = addItemA;
    }

    public String getAddItemB() {
        return addItemB;
    }

    public void setAddItemB(String addItemB) {
        this.addItemB = addItemB;
    }
}

==> ejc-dataexchange-api-3.0.0-20220305.074948-14-sources.jar: com/ejianc/business/dataexchange/vo/JzsVo.java <==
package com.ejianc.business.dataexchange.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;

public class JzsVo  {
    private static final long serialVersionUID = 1L;
    private String uid;
    private String name;



    private String compamy;    //单位

    private String idCode;  //通过身份证号计算年龄

    private String title;  //职称

    private String certificate; //证书

    private String registered; //注册单位

    private String management; //管理单位

    private String registeredNo; //注册编号

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date effactiveDate;//有效日期

    private String addItemA;//专业增项1；

    private String addItemB;//专业增项2

    private String addItemC;//专业增项3；

    private String addItemD;//专业增项4


    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }
    public String getAddItemC() {
        return addItemC;
    }

    public void setAddItemC(String addItemC) {
        this.addItemC = addItemC;
    }

    public String getAddItemD() {
        return addItemD;
    }

    public void setAddItemD(String addItemD) {
        this.addItemD = addItemD;
    }



    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCompamy() {
        return compamy;
    }

    public void setCompamy(String compamy) {
        this.compamy = compamy;
    }

    public String getIdCode() {
        return idCode;
    }

    public void setIdCode(String idCode) {
        this.idCode = idCode;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getCertificate() {
        return certificate;
    }

    public void setCertificate(String certificate) {
        this.certificate = certificate;
    }

    public String getRegistered() {
        return registered;
    }

    public void setRegistered(String registered) {
        this.registered = registered;
    }

    public String getManagement() {
        return management;
    }

    public void setManagement(String management) {
        this.management = management;
    }

    public String getRegisteredNo() {
        return registeredNo;
    }

    public void setRegisteredNo(String registeredNo) {
        this.registeredNo = registeredNo;
    }

    public Date getEffactiveDate() {
        return effactiveDate;
    }

    public void setEffactiveDate(Date effactiveDate) {
        this.effactiveDate = effactiveDate;
    }

    public String getAddItemA() {
        return addItemA;
    }

    public void setAddItemA(String addItemA) {
        this.addItemA = addItemA;
    }

    public String getAddItemB() {
        return addItemB;
    }

    public void setAddItemB(String addItemB) {
        this.addItemB = addItemB;
    }
}
